@@ -1,22 +1,22 @@
 import asyncio
-from helpers.entries import Entry
+from MT5TrdHelper.helpers.entries import Entry
 import time
 from typing import Tuple
 import pandas as pd
 from datetime import datetime
 from localconfig import config
-from connect.connection import Connection
+from MT5TrdHelper.connect.connection import Connection
 from MetaTrader5 import TIMEFRAME_H1, TIMEFRAME_H4, TIMEFRAME_M1
 from pymt5adapter import const
 from pymt5adapter.context import _ContextAwareBase
-from pymt5adapter.core import copy_rates_from_pos, copy_ticks_from, copy_rates
+from pymt5adapter.core import copy_rates_from_pos, copy_ticks_from, copy_rates, copy_rates_from
 from pymt5adapter.core import symbol_info as sym_info
 from pymt5adapter.core import symbol_info_tick
 from pymt5adapter.core import symbol_select
 from pymt5adapter.types import SymbolInfo
 from pymt5adapter.types import Union
 
-# connect_path = "D:\\DATA_SET_MACHINE_LEARNING\\trading_engine\\my_trading_system\\connect\\connection.ini"
+connect_path = "D:\\DATA_SET_MACHINE_LEARNING\\trading_engine\\my_trading_system\\connect\\connection.ini"
 
 
 def make_ohlcv(array_of_price):
@@ -44,13 +44,13 @@ class Symbol(_ContextAwareBase, Connection):
     first_tick = True
     last_tick = 0
 
-    def __init__(self, symbol: Union[str, SymbolInfo], timeframe, max_bars: int = None, terminal='xm_terminal_connection'):
+    def __init__(self, symbol: Union[str, SymbolInfo], timeframe, max_bars: int = None, terminal='five_prcnt_real_terminal_connection'):
         # -----------------------------------------------------+
         # * (START)  reading all the configuration and initializing connection class
         # -----------------------------------------------------+
         # config.read('exchange\\connection.ini')
         # ! for interactive python shell
-        # config.read(connect_path)
+        config.read(connect_path)
         # if terminal == 'GLOBAL':
         #     keyargs = dict(list(config.real_terminal_connection))
         # elif terminal == 'XM':
@@ -359,18 +359,26 @@ class Symbol(_ContextAwareBase, Connection):
                     self.name, self.timeframe, 1, 99999)
             return bars
 
-    def get_rates_bar(self, ohlcv: bool = True):
+    def get_rates_bar(self, ohlcv: bool = True, datetime_from: Union[datetime, int] = None, datetime_to: Union[datetime, int] = None,):
         """
         This will get array of bar data, if you want dataframe use make_ohlcv function
+        create date time like this 
+        "date_string = "2022-01-15"
+        date_format = "%Y-%m-%d"
+
+        date_object = datetime.strptime(date_string, date_format)"
+        If you want from to, don't use max bars when creating Symbol,
+        IF YOU USE 'datetime_from', 'datetime_to' is also REQUIRED
 
         """
         with self.connected:
             if self.max_bars:
                 # ! 1 for last candle, which is closed
                 bars = copy_rates(self.name, self.timeframe,
-                                  start_pos=1, count=self.max_bars)
+                                  start_pos=1, count=self.max_bars, datetime_from=datetime_from, datetime_to=datetime_to)
             else:
-                bars = copy_rates(self.name, self.timeframe)
+                bars = copy_rates(
+                    self.name, self.timeframe, datetime_from=datetime_from, datetime_to=datetime_to)
 
             if ohlcv:
                 df = make_ohlcv(bars)
@@ -746,11 +754,20 @@ if __name__ == "__main__":
     # * (END)  One way of doing it
     # -----------------------------------------------------+
 
-    sym = Symbol('EURJPY', const.TIMEFRAME_H1, 3000)
+    # sym = Symbol('EURJPY', const.TIMEFRAME_H1, 3000
+    sym = Symbol('EURJPY', const.TIMEFRAME_H1)
     # ! WE CAN ALSO CHANGE THE TIMEFRAME, LAST BAR VALUE WILL BE CHANGED TOO
     # sym.timeframe = const.TIMEFRAME_M1
     # rates_df = sym.get_rates_bar()
     # df = make_ohlcv(rates_df)
+    strt_date_string = "2023-01-01"
+    end_date_string = "2023-02-13"
+    date_format = "%Y-%m-%d"
+    strt_dt = datetime.strptime(strt_date_string, date_format)
+    end_dt = datetime.strptime(end_date_string, date_format)
+    df = sym.get_rates_bar(datetime_from=strt_dt, datetime_to=end_dt)
+    print(df)
+
     print(sym.high_bars)
     time = sym.time
     print(time)
