@@ -21,6 +21,10 @@ class Entry(enum.Enum, metaclass=MyEnumMeta):
     """
     Buy = 1,
     Sell = 2
+    Buy_Bet = 3
+    Sell_Bet = 4
+    HOLD = 5
+    EXIT = 6
 
     def __str__(self):
         return self.name
