@@ -1,12 +1,12 @@
-from helpers.entries import Entry
+from MT5TrdHelper.helpers.entries import Entry
 from pymt5adapter.types import OrderSendResult, TradePosition
 import pytz
 import pandas as pd
 import time
 from typing import Callable, Union
 from datetime import datetime, timedelta
-from exchange.symbol_base import Symbol
-from exchange.mt5_exchange import MT5Exchange
+from MT5TrdHelper.exchange.symbol_base import Symbol
+from MT5TrdHelper.exchange.mt5_exchange import MT5Exchange
 # from helpers.database_helpers import get_hidden_be_db, get_hidden_sl_db, get_hidden_tp_db, get_hidden_trl_sl_db, insert_hidden_be_sl_db, insert_hidden_sl_db, insert_hidden_tp_db, insert_update_symbol_wave_info, insert_updt_hidden_trl_sl_db
 import pymt5adapter as mt5
 from pymt5adapter.const import ORDER_TIME, ORDER_TYPE, TIMEFRAME_M1, TRADE_ACTION, TRADE_RETCODE
